/****************************************************************************

	SATELITE.H

	Include header for applications using the KCT Satellite Rotor and Radio
    Interface driver for Windows 95, ie. RR.DLL.

	(C) Copyright 1994, David A. Hoatson, KC6WYG. All Rights Reserved.
	(C) Copyright 1995-1996, Joe Holman, AD7D, ex-KA7LDN.  All Righst Reserved.

	Created: April 10, 1994; DAH

	Modifcation History

	When		Who		        What
	---------	---		        ---------------------------------------------------
	09.15.96	AD7D, ex-KA7LDN	Ported to Windows 95.

****************************************************************************/

// windows.h should be included before this file.

#ifndef _SATELITE_H
#define _SATELITE_H

typedef unsigned short STATUS;

#define ERR_OK			    0
#define ERR_BADDEVICEID		2
#define ERR_INVALIDHANDLE	5
#define ERR_INVALIDPARAM	11
#define ERR_ACCESSDENIED	13
#define ERR_OUTOFHANDLES	14
#define ERR_INVALIDCMD		15	// macro processing error
#define ERR_UNKNOWNSTATUS	16	// RadioGet...() called when radio not enabled
#define ERR_NO_RADIOS_DEFINED 17

#define STATUS_ELEVSTALLED	0x1000
#define STATUS_AZIMSTALLED	0x2000

#define RADIOMODE_FM		0x0001
#define RADIOMODE_NFM		0x1001
#define RADIOMODE_USB		0x0002
#define RADIOMODE_LSB		0x0004
#define RADIOMODE_CW		0x0008
#define RADIOMODE_NCW		0x1008

#define ACCESS_READONLY		0x0000	// open device for reading only
#define ACCESS_WRITEONLY	0x0001	// changed to READWRITE internally!
#define ACCESS_READWRITE	0x0002	// open device for reading and writing

#define SATBAND_RX_144MHZ  0x0001   //  bands supported by radio
#define SATBAND_RX_430MHZ  0x0002
#define SATBAND_RX_1200MHZ 0x0004
#define SATBAND_RX_2400MHZ 0x0008

#define SATBAND_TX_144MHZ   0x0100
#define SATBAND_TX_430MHZ   0x0200
#define SATBAND_TX_1200MHZ  0x0400
#define SATBAND_TX_2400MHZ  0x0800


#define DLLFUNC	__declspec ( dllexport ) WINAPI     // force .lib creatioin   


//	Puts the Configuration dialog up for the user to use.
//
LONG	DLLFUNC RotorRadioConfigure ( HWND, HANDLE );

//  Returns the number of az/el rotors.
//
UINT	DLLFUNC RotorGetNumDevs( VOID );

//  Opens a specific rotor device
//
STATUS	DLLFUNC RotorOpen( VOID );

//  Closes a rotor device opened with RotorOpen
//
STATUS	DLLFUNC RotorClose( VOID );

//  Moves the rotor to a specific position.
//
STATUS	DLLFUNC RotorSetPosition(
		UINT		wAzimuth,	    // azimuth to move to
		UINT		wElevation,	    // elevation to move to 
		DWORD		dwFlags );	    // any flags needed for the position (set to NULL)

//  Gets the current rotor position as an degree value.
//
STATUS	DLLFUNC RotorGetPosition(
		LPWORD	lpwAzimuth,	        // current azimuth
		LPWORD	lpwElevation );	    // current elevation 

//	Gets the current rotor position as an analog value.
//
STATUS	DLLFUNC RotorGetPositionAnalog(
		LPWORD	lpwAzimuth,	         // current azimuth
		LPWORD	lpwElevation );	     // current elevation

//  Returns the number of radio devices.
//
UINT	DLLFUNC RadioGetNumDevs( VOID );

//  Opens a specific radio device.
//
STATUS	DLLFUNC RadioOpen( DWORD );

//  Closes a radio device opened with RadioOpen.
//
STATUS	DLLFUNC RadioClose( VOID );

//  Tunes the radio to a specific frequency.
//
STATUS	DLLFUNC RadioSetFrequency(
		DWORD		dwRxFreq,	    // receive frequency
		DWORD		dwTxFreq,	    // transmit frequency 
		DWORD		dwFlags );	    // any flags needed for the driver (set to NULL)

//  Set the receive/transmit mode for the radio.
//
STATUS	DLLFUNC RadioSetMode(
		DWORD		dwRxMode,	    // receive mode
		DWORD		dwTxMode,	    // transmit mode
		DWORD		dwFlags );	    // any flags needed for the driver (set to NULL)

//  Get's the frequency that was passed to RadioSetFrequency.
//	Note:	This API does not query the radio, but just conviently returns
//			the value passed to RadioSetFrequency.
//
STATUS	DLLFUNC RadioGetFrequency(
		LPDWORD		lpdwRxFreq,	    // receive frequency
		LPDWORD		lpdwTxFreq );	// transmit frequency 

//  Get's the mode that was passed to RadioSetMode.
//	Note:	This API does not query the radio, but just conviently returns
//			the value passed to RadioSetMode.
//  
STATUS	DLLFUNC RadioGetMode(
		LPDWORD		lpdwRxMode,	    // receive mode
		LPDWORD		lpdwTxMode );	// transmit mode

#endif
